@@ -1,9 +1,9 @@
+import re
 from dataclasses import dataclass, field
 from time import sleep, time
 from typing import Optional
 
 import httpx
-from bs4 import BeautifulSoup
 
 
 class MiraiTranslateError(Exception):
@@ -12,6 +12,15 @@ class MiraiTranslateError(Exception):
 
 @dataclass
 class Client:
+    """Mirai Translate Client.
+
+    Attributes
+    ----------
+    delay_sec : int
+        Minimum request interval (the default is 6 because we can only request up to
+        10 per minute).
+    """
+
     delay_sec: Optional[int] = 6
     _cli: httpx.Client = field(
         default=httpx.Client(base_url="https://miraitranslate.com"), init=False
@@ -31,10 +40,14 @@ class Client:
 
     def _refresh_tran(self):
         self._assure_deley()
-        res = self._cli.get("/trial")
+        try:
+            res = self._cli.get("/trial")
+        except httpx.ReadTimeout:
+            raise MiraiTranslateError("Response from Mirai Translate timed out")
         self._prev_req_time = time()
-        soup = BeautifulSoup(res.content, "html.parser")
-        self._tran = soup.find(id="tranInput")["value"]
+        self._tran = (
+            re.search(rb'var tran = "(.+?)";', res.content).group(1).decode("utf-8")
+        )
 
     def _translate(self, text: str, source: str, target: str) -> str:
         payload = dict(
@@ -47,7 +60,10 @@ class Client:
             tran=self._tran,
         )
         self._assure_deley()
-        res = self._cli.post("/trial/translate.php", data=payload)
+        try:
+            res = self._cli.post("/trial/translate.php", data=payload)
+        except httpx.ReadTimeout:
+            raise MiraiTranslateError("Response from Mirai Translate timed out")
         self._prev_req_time = time()
         j = res.json()
 
@@ -64,6 +80,26 @@ class Client:
         return j["outputs"][0]["output"]
 
     def translate(self, text: str, source: str, target: str) -> str:
+        """Translate `text` from `source` to `target`.
+
+        Parameters
+        ----------
+        text : str
+            Source text.
+        source : str
+            Source language ("en", "ja", ...).
+        target : str
+            Target language ("en", "ja", ...).
+
+        Raises
+        ------
+        MiraiTranslateError
+
+        Returns
+        -------
+        str
+            Translated text.
+        """
         try:
             return self._translate(text, source, target)
         except MiraiTranslateError:
